<?php
// $Horde: horde/config/mime_drivers.php.dist,v 1.11.2.2 2001/11/30 14:49:12 jan Exp $

/**
 * Decide which output drivers you want to activate.
 * Right now, the choices are:
 *
 * php:      The internal PHP4 syntax highlighting engine
 * enscript: GNU enscript
 * tgz:      Gzipped tarballs
 * rar:      RAR archives
 * msword:   Microsoft Word files via wvHtml
 * excel:    Microsoft Excel files via xlHtml
 * vcard:    vCards
 */

$mime_drivers_map['horde']['registered'] = array(
    'php', 'enscript', 'tgz', 'rar', 'msword', 'excel', 'vcard');

/**
 * If you want to specifically override any MIME type to be
 * handled by a specific driver, then enter it here.  Normally,
 * this is safe to leave, but it's useful when multiple drivers
 * handle the same MIME type, and you want to specify exactly
 * which one should handle it.
 */

$mime_drivers_map['horde']['overrides'] = array();

/**
 * Driver specific settings.  Here, you have to configure each
 * driver which you chose to activate above.  Default settings have
 * been filled in for them, and if you haven't activated it, then
 * just leave it as it is - it won't get loaded.
 *
 * The 'handles' setting below shouldn't be changed in most 
 * circumstances.  It registers a set of MIME type that the driver
 * can handle.  The 'x-extension' MIME type is a special one to
 * Horde that maps a file extension to a MIME type.  It's useful
 * when you know that all files ending in '.c' are C files, for
 * example.
 *
 * The 'icons' entry is for the driver to register various icons
 * for the MIME types it handles.  The array consists of a 
 * 'default' icon for that driver, and can also include specific
 * MIME-types which can have their own icons.
 *
 */

/**
 * Default driver settings
 */

$mime_drivers['horde']['default']['icons'] = array(
        'default'                       => 'text.gif',
        'application/x-gzip'            => 'compressed.gif',
        'application/pdf'               => 'pdf.gif',
        'application/pgp-signature'     => 'encryption.gif', 
        'application/x-pkcs7-signature' => 'encryption.gif', 
        'image/bmp'                     => 'image.gif',
        'image/gif'                     => 'image.gif',
        'image/jpeg'                    => 'image.gif',
        'image/png'                     => 'image.gif',
        'message/rfc822'                => 'mail.gif' );

/**
 * PHP driver settings
 */

$mime_drivers['horde']['php']['handles'] = array(
    'x-extension/php', 'x-extension/php3', 'x-extension/phps',
    'x-extension/php3s');

$mime_drivers['horde']['php']['icons'] = array(
    'default' => 'php.gif');

/**
 * GNU Enscript driver settings
 */

/* Location of the enscript binary */
$mime_drivers['horde']['enscript']['location'] = '/usr/local/bin/enscript';

$mime_drivers['horde']['enscript']['inline'] = false;

$mime_drivers['horde']['enscript']['handles'] = array(
    'text/html', 'x-extension/pl', 'x-extension/c',
    'text/xml', 'application/x-sh', 'application/x-javascript',
    'x-extension/java', 'x-extension/c', 'x-extension/h',
    'x-extension/cpp');

$mime_drivers['horde']['enscript']['icons'] = array(
    'default'   => 'text.gif',
    'text/html' => 'html.gif',
    'text/xml'  => 'html.gif');

/**
 * GZipped Tar driver settings
 */

/* Location of the tar binary */
$mime_drivers['horde']['tgz']['location'] = '/bin/tar';
$mime_drivers['horde']['tgz']['inline'] = true;
$mime_drivers['horde']['tgz']['handles'] = array(
    'x-extension/tgz');
$mime_drivers['horde']['tgz']['icons'] = array(
    'default' => 'compressed.gif');

/**
 * RAR archive driver settings
 */

/* Location of the rar binary */
$mime_drivers['horde']['rar']['location'] = '/usr/bin/rar';
$mime_drivers['horde']['rar']['inline'] = true;
$mime_drivers['horde']['rar']['handles'] = array('x-extension/rar');
$mime_drivers['horde']['tgz']['icons'] = array('default' => 'compressed.gif');

/**
 * MSWord driver settings
 * This driver requires wvWare (www.wvware.com) to be installed
 */

/* Location of the wvHtml binary */
$mime_drivers['horde']['msword']['location'] = '/usr/local/bin/wvHtml';
$mime_drivers['horde']['msword']['inline'] = true;
$mime_drivers['horde']['msword']['handles'] = array(
    'application/msword', 'text/rtf');
$mime_drivers['horde']['msword']['icons'] = array(
    'default' => 'msword.gif');

/**
 * Excel driver settings
 * This drivers requirs xlHtml (www.xlhtml.org) to be installed
 */

/* Location of the xlHtml binary */
$mime_drivers['horde']['excel']['location'] = '/usr/local/bin/xlhtml';
$mime_drivers['horde']['excel']['inline'] = false;
$mime_drivers['horde']['excel']['handles'] = array(
    'application/vnd.ms-excel', 'application/msexcel');
$mime_drivers['horde']['excel']['icons'] = array(
    'default' => 'excel.gif');

/**
 * vCard driver settings
 */

$mime_drivers['horde']['vcard']['handles'] = array(
    'text/x-vcard');

?>
